; ======================================================;
;                                                       ;
;  rasapi32.inc for Easy Code 2.0 64-bit Masm projects  ;
;                  (version 1.0.2)                      ;
;                                                       ;
;          Copyright  Ramon Sala - 2017-2021           ;
;                                                       ;
; ======================================================;

IFNDEF RASAPI32_INC
RASAPI32_INC    EQU 1

CNLEN                                           EQU     15
LM20_CNLEN                                      EQU     15
DNLEN                                           EQU     CNLEN
LM20_DNLEN                                      EQU     LM20_CNLEN
UNLEN                                           EQU     256
PWLEN                                           EQU     256

NETBIOS_NAME_LEN                                EQU     16

RAS_MaxDeviceType                               EQU     16
RAS_MaxPhoneNumber                              EQU     128
RAS_MaxIpAddress                                EQU     15
RAS_MaxIpxAddress                               EQU     21

IF (NTDDI_VERSION GE NTDDI_WINNT4)
    RAS_MaxEntryName                            EQU     256
    RAS_MaxDeviceName                           EQU     128
    RAS_MaxCallbackNumber                       EQU     RAS_MaxPhoneNumber
ELSE
    RAS_MaxEntryName                            EQU     20
    RAS_MaxDeviceName                           EQU     32
    RAS_MaxCallbackNumber                       EQU     48
ENDIF

RAS_MaxAreaCode                                 EQU     10
RAS_MaxPadType                                  EQU     32
RAS_MaxX25Address                               EQU     200
RAS_MaxFacilities                               EQU     200
RAS_MaxUserData                                 EQU     200

RASCS_PAUSED                                    EQU     01000H
RASCS_DONE                                      EQU     02000H

;RASCONNSTATE enumeration
RASCS_OpenPort                                  EQU     0
RASCS_PortOpened                                EQU     1
RASCS_ConnectDevice                             EQU     2
RASCS_DeviceConnected                           EQU     3
RASCS_AllDevicesConnected                       EQU     4
RASCS_Authenticate                              EQU     5
RASCS_AuthNotify                                EQU     6
RASCS_AuthRetry                                 EQU     7
RASCS_AuthCallback                              EQU     8
RASCS_AuthChangePassword                        EQU     9
RASCS_AuthProject                               EQU     10
RASCS_AuthLinkSpeed                             EQU     11
RASCS_AuthAck                                   EQU     12
RASCS_ReAuthenticate                            EQU     13
RASCS_Authenticated                             EQU     14
RASCS_PrepareForCallback                        EQU     15
RASCS_WaitForModemReset                         EQU     16
RASCS_WaitForCallback                           EQU     17
RASCS_Projected                                 EQU     18
RASCS_StartAuthentication                       EQU     19
RASCS_CallbackComplete                          EQU     20
RASCS_LogonNetwork                              EQU     21
RASCS_SubEntryConnected                         EQU     22
RASCS_SubEntryDisconnected                      EQU     23
RASCS_Interactive                               EQU     RASCS_PAUSED + 1
RASCS_RetryAuthentication                       EQU     RASCS_PAUSED + 2
RASCS_CallbackSetByCaller                       EQU     RASCS_PAUSED + 3
RASCS_PasswordExpired                           EQU     RASCS_PAUSED + 4
RASCS_Connected                                 EQU     RASCS_DONE
RASCS_Disconnected                              EQU     RASCS_DONE + 1

RDEOPT_UsePrefixSuffix                          EQU     00000001H
RDEOPT_PausedStates                             EQU     00000002H
RDEOPT_IgnoreModemSpeaker                       EQU     00000004H
RDEOPT_SetModemSpeaker                          EQU     00000008H
RDEOPT_IgnoreSoftwareCompression                EQU     00000010H
RDEOPT_SetSoftwareCompression                   EQU     00000020H
RDEOPT_DisableConnectedUI                       EQU     00000040H
RDEOPT_DisableReconnectUI                       EQU     00000080H
RDEOPT_DisableReconnect                         EQU     00000100H
RDEOPT_NoUser                                   EQU     00000200H
RDEOPT_PauseOnScript                            EQU     00000400H

RASDIALEVENT                                    TEXTEQU <RasDialEvent>
WM_RASDIALEVENT                                 EQU     0CCCDH

RASEO_UseCountryAndAreaCodes                    EQU     00000001H
RASEO_SpecificIpAddr                            EQU     00000002H
RASEO_SpecificNameServers                       EQU     00000004H
RASEO_IpHeaderCompression                       EQU     00000008H
RASEO_RemoteDefaultGateway                      EQU     00000010H
RASEO_DisableLcpExtensions                      EQU     00000020H
RASEO_TerminalBeforeDial                        EQU     00000040H
RASEO_TerminalAfterDial                         EQU     00000080H
RASEO_ModemLights                               EQU     00000100H
RASEO_SwCompression                             EQU     00000200H
RASEO_RequireEncryptedPw                        EQU     00000400H
RASEO_RequireMsEncryptedPw                      EQU     00000800H
RASEO_RequireDataEncryption                     EQU     00001000H
RASEO_NetworkLogon                              EQU     00002000H
RASEO_UseLogonCredentials                       EQU     00004000H
RASEO_PromoteAlternates                         EQU     00008000H
RASEO_SecureLocalFiles                          EQU     00010000H

RASNP_NetBEUI                                   EQU     00000001H
RASNP_Ipx                                       EQU     00000002H
RASNP_Ip                                        EQU     00000004H

RASFP_Ppp                                       EQU     00000001H
RASFP_Slip                                      EQU     00000002H
RASFP_Ras                                       EQU     00000004H

RASDT_Modem                                     TEXTEQU <modem>
RASDT_Isdn                                      TEXTEQU <isdn>
RASDT_X25                                       TEXTEQU <x25>

RASCN_Connection                                EQU     00000001H
RASCN_Disconnection                             EQU     00000002H
RASCN_BandwidthAdded                            EQU     00000004H
RASCN_BandwidthRemoved                          EQU     00000008H

RASEDM_DialAll                                  EQU     1
RASEDM_DialAsNeeded                             EQU     2

RASIDS_Disabled                                 EQU     0FFFFFFFFH
RASIDS_UseGlobalValue                           EQU     0

RASADFLG_PositionDlg                            EQU     00000001H

RASCM_UserName                                  EQU     00000001H
RASCM_Password                                  EQU     00000002H
RASCM_Domain                                    EQU     00000004H

RASADP_DisableConnectionQuery                   EQU     0
RASADP_LoginSessionDisable                      EQU     1
RASADP_SavedAddressesLimit                      EQU     2
RASADP_FailedConnectionTimeout                  EQU     3
RASADP_ConnectionQueryTimeout                   EQU     4


;======================================== Structures ======================================;
RASCONNA STRUCT ALIGNMODE
    dwSize       DD    ?
    hrasconn     XWORD ?
    szEntryName  DB    (RAS_MaxEntryName + 1) DUP(?)
    szDeviceType DB    (RAS_MaxDeviceType + 1) DUP(?)
    szDeviceName DB    (RAS_MaxDeviceName + 1) DUP(?)
    szPhonebook  DB    (MAX_PATH) DUP(?)
    dwSubEntry   DD    ?
RASCONNA ENDS

RASCONNW STRUCT ALIGNMODE
    dwSize       DD    ?
    hrasconn     XWORD ?
    szEntryName  DW    (RAS_MaxEntryName + 1) DUP(?)
    szDeviceType DW    (RAS_MaxDeviceType + 1) DUP(?)
    szDeviceName DW    (RAS_MaxDeviceName + 1) DUP(?)
    szPhonebook  DW    (MAX_PATH) DUP(?)
    dwSubEntry   DD    ?
RASCONNW ENDS

RASCONNSTATUSA STRUCT ALIGNMODE
    dwSize        DD    ?
    rasconnstate  XWORD ?
    dwError       DD    ?
    szDeviceType  DB    (RAS_MaxDeviceType + 1) DUP(?)
    szDeviceName  DB    (RAS_MaxDeviceName + 1) DUP(?)
    szPhoneNumber DB    (RAS_MaxPhoneNumber + 1) DUP(?)
RASCONNSTATUSA ENDS

RASCONNSTATUSW STRUCT ALIGNMODE
    dwSize        DD    ?
    rasconnstate  XWORD ?
    dwError       DD    ?
    szDeviceType  DW    (RAS_MaxDeviceType + 1) DUP(?)
    szDeviceName  DW    (RAS_MaxDeviceName + 1) DUP(?)
    szPhoneNumber DW    (RAS_MaxPhoneNumber + 1) DUP(?)
RASCONNSTATUSW ENDS

RASDIALPARAMSA STRUCT ALIGNMODE
    dwSize           DD ?
    szEntryName      DB (RAS_MaxEntryName + 1) DUP(?)
    szPhoneNumber    DB (RAS_MaxPhoneNumber + 1) DUP(?)
    szCallbackNumber DB (RAS_MaxCallbackNumber + 1) DUP(?)
    szUserName       DB (UNLEN + 1) DUP(?)
    szPassword       DB (PWLEN + 1) DUP(?)
    szDomain         DB (DNLEN + 1) DUP(?)
    dwSubEntry       DD ?
    dwCallbackId     DD ?
RASDIALPARAMSA ENDS

RASDIALPARAMSW STRUCT ALIGNMODE
    dwSize           DD ?
    szEntryName      DW (RAS_MaxEntryName + 1) DUP(?)
    szPhoneNumber    DW (RAS_MaxPhoneNumber + 1) DUP(?)
    szCallbackNumber DW (RAS_MaxCallbackNumber + 1) DUP(?)
    szUserName       DW (UNLEN + 1) DUP(?)
    szPassword       DW (PWLEN + 1) DUP(?)
    szDomain         DW (DNLEN + 1) DUP(?)
    dwSubEntry       DD ?
    dwCallbackId     DD ?
RASDIALPARAMSW ENDS

RASDIALEXTENSIONS STRUCT ALIGNMODE
    dwSize      DD    ?
    dwfOptions  DD    ?
    hwndParent  XWORD ?
    reserved    DD    ?
RASDIALEXTENSIONS ENDS

RASENTRYNAMEA STRUCT ALIGNMODE
    dwSize      DD ?
    szEntryName DB (RAS_MaxEntryName + 1) DUP(?)
RASENTRYNAMEA ENDS

RASENTRYNAMEW STRUCT ALIGNMODE
    dwSize      DD ?
    szEntryName DW (RAS_MaxEntryName + 1) DUP(?)
RASENTRYNAMEW ENDS

RASAMBA STRUCT ALIGNMODE
    dwSize          DD ?
    dwError         DD ?
    szNetBiosError  DB (NETBIOS_NAME_LEN + 1) DUP(?)
    bLana           DB ?
RASAMBA ENDS

RASAMBW STRUCT ALIGNMODE
    dwSize          DD ?
    dwError         DD ?
    szNetBiosError  DW (NETBIOS_NAME_LEN + 1) DUP(?)
    bLana           DB ?
RASAMBW ENDS

RASPPPNBFA STRUCT ALIGNMODE
    dwSize            DD ?
    dwError           DD ?
    dwNetBiosError    DD ?
    szNetBiosError    DB (NETBIOS_NAME_LEN + 1) DUP(?)
    szWorkstationName DB (NETBIOS_NAME_LEN + 1) DUP(?)
    bLana             DB ?
RASPPPNBFA ENDS

RASPPPNBFW STRUCT ALIGNMODE
    dwSize            DD ?
    dwError           DD ?
    dwNetBiosError    DD ?
    szNetBiosError    DW (NETBIOS_NAME_LEN + 1) DUP(?)
    szWorkstationName DW (NETBIOS_NAME_LEN + 1) DUP(?)
    bLana             DB ?
RASPPPNBFW ENDS

RASPPPIPXA STRUCT ALIGNMODE
    dwSize       DD ?
    dwError      DD ?
    szIpxAddress DB (RAS_MaxIpxAddress + 1) DUP(?)
RASPPPIPXA ENDS

RASPPPIPXW STRUCT ALIGNMODE
    dwSize       DD ?
    dwError      DD ?
    szIpxAddress DW (RAS_MaxIpxAddress + 1) DUP(?)
RASPPPIPXW ENDS

RASPPPIPA STRUCT ALIGNMODE
    dwSize            DD ?
    dwError           DD ?
    szIpAddress       DB (RAS_MaxIpAddress + 1) DUP(?)
    szServerIpAddress DB (RAS_MaxIpAddress + 1) DUP(?)
RASPPPIPA ENDS

RASPPPIPW STRUCT ALIGNMODE
    dwSize            DD ?
    dwError           DD ?
    szIpAddress       DW (RAS_MaxIpAddress + 1) DUP(?)
    szServerIpAddress DW (RAS_MaxIpAddress + 1) DUP(?)
RASPPPIPW ENDS

RASPPPLCP STRUCT ALIGNMODE
    dwSize   DD   ?
    fBundled BOOL ?
RASPPPLCP ENDS

RASSLIPA STRUCT ALIGNMODE
    dwSize      DD ?
    dwError     DD ?
    szIpAddress DB (RAS_MaxIpAddress + 1) DUP(?)
RASSLIPA ENDS

RASSLIPW STRUCT ALIGNMODE
    dwSize      DD ?
    dwError     DD ?
    szIpAddress DB (RAS_MaxIpAddress + 1) DUP(?)
RASSLIPW ENDS

RASDEVINFOA STRUCT ALIGNMODE
    dwSize       DD ?
    szDeviceType DB (RAS_MaxDeviceType + 1) DUP(?)
    szDeviceName DB (RAS_MaxDeviceName + 1) DUP(?)
RASDEVINFOA ENDS

RASDEVINFOW STRUCT ALIGNMODE
    dwSize       DD ?
    szDeviceType DW (RAS_MaxDeviceType + 1) DUP(?)
    szDeviceName DW (RAS_MaxDeviceName + 1) DUP(?)
RASDEVINFOW ENDS

RASCTRYINFO STRUCT ALIGNMODE
    dwSize              DD ?
    dwCountryID         DD ?
    dwNextCountryID     DD ?
    dwCountryCode       DD ?
    dwCountryNameOffset DD ?
RASCTRYINFO ENDS
RASCTRYINFOA EQU <RASCTRYINFO>
RASCTRYINFOW EQU <RASCTRYINFO>

RASIPADDR STRUCT ALIGNMODE
    a   DB ?
    b   DB ?
    _c  DB ?
    d   DB ?
RASIPADDR ENDS

RASENTRYA STRUCT ALIGNMODE
    dwSize                      DD ?
    dwfOptions                  DD ?
    dwCountryID                 DD ?
    dwCountryCode               DD ?
    szAreaCode                  DB (RAS_MaxAreaCode + 1) DUP(?)
    szLocalPhoneNumber          DB (RAS_MaxPhoneNumber + 1) DUP(?)
    dwAlternateOffset           DD ?
    ipaddr                      RASIPADDR <>
    ipaddrDns                   RASIPADDR <>
    ipaddrDnsAlt                RASIPADDR <>
    ipaddrWins                  RASIPADDR <>
    ipaddrWinsAlt               RASIPADDR <>
    dwFrameSize                 DD ?
    dwfNetProtocols             DD ?
    dwFramingProtocol           DD ?
    szScript                    DB (MAX_PATH) DUP(?)
    szAutodialDll               DB (MAX_PATH) DUP(?)
    szAutodialFunc              DB (MAX_PATH) DUP(?)
    szDeviceType                DB (RAS_MaxDeviceType + 1) DUP(?)
    szDeviceName                DB (RAS_MaxDeviceName + 1) DUP(?)
    szX25PadType                DB (RAS_MaxPadType + 1) DUP(?)
    szX25Address                DB (RAS_MaxX25Address + 1) DUP(?)
    szX25Facilities             DB (RAS_MaxFacilities + 1) DUP(?)
    szX25UserData               DB (RAS_MaxUserData + 1) DUP(?)
    dwChannels                  DD ?
    dwReserved1                 DD ?
    dwReserved2                 DD ?
    dwSubEntries                DD ?
    dwDialMode                  DD ?
    dwDialExtraPercent          DD ?
    dwDialExtraSampleSeconds    DD ?
    dwHangUpExtraPercent        DD ?
    dwHangUpExtraSampleSeconds  DD ?
    dwIdleDisconnectSeconds     DD ?
RASENTRYA ENDS

RASENTRYW STRUCT ALIGNMODE
    dwSize                      DD ?
    dwfOptions                  DD ?
    dwCountryID                 DD ?
    dwCountryCode               DD ?
    szAreaCode                  DW (RAS_MaxAreaCode + 1) DUP(?)
    szLocalPhoneNumber          DW (RAS_MaxPhoneNumber + 1) DUP(?)
    dwAlternateOffset           DD ?
    ipaddr                      RASIPADDR <>
    ipaddrDns                   RASIPADDR <>
    ipaddrDnsAlt                RASIPADDR <>
    ipaddrWins                  RASIPADDR <>
    ipaddrWinsAlt               RASIPADDR <>
    dwFrameSize                 DD ?
    dwfNetProtocols             DD ?
    dwFramingProtocol           DD ?
    szScript                    DW (MAX_PATH) DUP(?)
    szAutodialDll               DW (MAX_PATH) DUP(?)
    szAutodialFunc              DW (MAX_PATH) DUP(?)
    szDeviceType                DW (RAS_MaxDeviceType + 1) DUP(?)
    szDeviceName                DW (RAS_MaxDeviceName + 1) DUP(?)
    szX25PadType                DW (RAS_MaxPadType + 1) DUP(?)
    szX25Address                DW (RAS_MaxX25Address + 1) DUP(?)
    szX25Facilities             DW (RAS_MaxFacilities + 1) DUP(?)
    szX25UserData               DW (RAS_MaxUserData + 1) DUP(?)
    dwChannels                  DD ?
    dwReserved1                 DD ?
    dwReserved2                 DD ?
    dwSubEntries                DD ?
    dwDialMode                  DD ?
    dwDialExtraPercent          DD ?
    dwDialExtraSampleSeconds    DD ?
    dwHangUpExtraPercent        DD ?
    dwHangUpExtraSampleSeconds  DD ?
    dwIdleDisconnectSeconds     DD ?
RASENTRYW ENDS

RASADPARAMS STRUCT ALIGNMODE
    dwSize      DD    ?
    hwndOwner   XWORD ?
    dwFlags     DD    ?
    xDlg        DD    ?
    yDlg        DD    ?
RASADPARAMS ENDS

RASSUBENTRYA STRUCT ALIGNMODE
    dwSize              DD ?
    dwfFlags            DD ?
    szDeviceType        DB (RAS_MaxDeviceType + 1) DUP(?)
    szDeviceName        DB (RAS_MaxDeviceName + 1) DUP(?)
    szLocalPhoneNumber  DB (RAS_MaxPhoneNumber + 1) DUP(?)
    dwAlternateOffset   DD ?
RASSUBENTRYA ENDS

RASSUBENTRYW STRUCT ALIGNMODE
    dwSize              DD ?
    dwfFlags            DD ?
    szDeviceType        DW (RAS_MaxDeviceType + 1) DUP(?)
    szDeviceName        DW (RAS_MaxDeviceName + 1) DUP(?)
    szLocalPhoneNumber  DW (RAS_MaxPhoneNumber + 1) DUP(?)
    dwAlternateOffset   DD ?
RASSUBENTRYW ENDS

RASCREDENTIALSA STRUCT ALIGNMODE
    dwSize      DD ?
    dwMask      DD ?
    szUserName  DB (UNLEN + 1) DUP(?)
    szPassword  DB (PWLEN + 1) DUP(?)
    szDomain    DB (DNLEN + 1) DUP(?)
RASCREDENTIALSA ENDS

RASCREDENTIALSW STRUCT ALIGNMODE
    dwSize      DD ?
    dwMask      DD ?
    szUserName  DW (UNLEN + 1) DUP(?)
    szPassword  DW (PWLEN + 1) DUP(?)
    szDomain    DW (DNLEN + 1) DUP(?)
RASCREDENTIALSW ENDS

RASAUTODIALENTRYA STRUCT ALIGNMODE
    dwSize            DD ?
    dwFlags           DD ?
    dwDialingLocation DD ?  
    szEntry           DB (RAS_MaxEntryName + 1) DUP(?)
RASAUTODIALENTRYA ENDS

RASAUTODIALENTRYW STRUCT ALIGNMODE
    dwSize            DD ?
    dwFlags           DD ?
    dwDialingLocation DD ?  
    szEntry           DW (RAS_MaxEntryName + 1) DUP(?)
RASAUTODIALENTRYW ENDS


;======================================== Functions =======================================;
DDMGetPhonebookInfo PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
DwCloneEntry PROTO :XWORD,:XWORD,:XWORD
DwDeleteSubEntry PROTO :XWORD,:XWORD,:XWORD
DwEnumEntriesForAllUsers PROTO :XWORD,:XWORD,:XWORD
DwEnumEntryDetails PROTO :XWORD,:XWORD,:XWORD,:XWORD
DwRasRefreshKerbScCreds PROTO :XWORD
DwRasUninitialize PROTO
RasAutoDialSharedConnection PROTO
RasAutodialAddressToNetwork PROTO :XWORD,:XWORD,:XWORD
RasAutodialEntryToNetwork PROTO :XWORD,:XWORD,:XWORD
RasClearConnectionStatistics PROTO :XWORD
RasClearLinkStatistics PROTO :XWORD,:XWORD
RasConnectionNotificationA PROTO :XWORD,:XWORD,:XWORD
RasConnectionNotificationW PROTO :XWORD,:XWORD,:XWORD
RasCreatePhonebookEntryA PROTO :XWORD,:XWORD
RasCreatePhonebookEntryW PROTO :XWORD,:XWORD
RasDeleteEntryA PROTO :XWORD,:XWORD
RasDeleteEntryW PROTO :XWORD,:XWORD
RasDeleteSubEntryA PROTO :XWORD,:XWORD,:XWORD
RasDeleteSubEntryW PROTO :XWORD,:XWORD,:XWORD
RasDialA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasDialW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasDialWow PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasEditPhonebookEntryA PROTO :XWORD,:XWORD,:XWORD
RasEditPhonebookEntryW PROTO :XWORD,:XWORD,:XWORD
RasEnumAutodialAddressesA PROTO :XWORD,:XWORD,:XWORD
RasEnumAutodialAddressesW PROTO :XWORD,:XWORD,:XWORD
RasEnumConnectionsA PROTO :XWORD,:XWORD,:XWORD
RasEnumConnectionsW PROTO :XWORD,:XWORD,:XWORD
RasEnumConnectionsWow PROTO :XWORD,:XWORD,:XWORD
RasEnumDevicesA PROTO :XWORD,:XWORD,:XWORD
RasEnumDevicesW PROTO :XWORD,:XWORD,:XWORD
RasEnumEntriesA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasEnumEntriesW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasEnumEntriesWow PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasFreeEapUserIdentityA PROTO :XWORD
RasFreeEapUserIdentityW PROTO :XWORD
RasGetAutodialAddressA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasGetAutodialAddressW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasGetAutodialEnableA PROTO :XWORD,:XWORD
RasGetAutodialEnableW PROTO :XWORD,:XWORD
RasGetAutodialParamA PROTO :XWORD,:XWORD,:XWORD
RasGetAutodialParamW PROTO :XWORD,:XWORD,:XWORD
RasGetConnectResponse PROTO :XWORD,:XWORD
RasGetConnectStatusA PROTO :XWORD,:XWORD
RasGetConnectStatusW PROTO :XWORD,:XWORD
RasGetConnectStatusWow PROTO :XWORD,:XWORD
RasGetConnectionStatistics PROTO :XWORD,:XWORD
RasGetCountryInfoA PROTO :XWORD,:XWORD
RasGetCountryInfoW PROTO :XWORD,:XWORD
RasGetCredentialsA PROTO :XWORD,:XWORD,:XWORD
RasGetCredentialsW PROTO :XWORD,:XWORD,:XWORD
RasGetCustomAuthDataA PROTO :XWORD,:XWORD,:XWORD,:XWORD
RasGetCustomAuthDataW PROTO :XWORD,:XWORD,:XWORD,:XWORD
RasGetEapUserDataA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasGetEapUserDataW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasGetEapUserIdentityA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasGetEapUserIdentityW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasGetEntryDialParamsA PROTO :XWORD,:XWORD,:XWORD
RasGetEntryDialParamsW PROTO :XWORD,:XWORD,:XWORD
RasGetEntryHrasconnA PROTO :XWORD,:XWORD,:XWORD
RasGetEntryHrasconnW PROTO :XWORD,:XWORD,:XWORD
RasGetEntryPropertiesA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasGetEntryPropertiesW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasGetErrorStringA PROTO :XWORD,:XWORD,:XWORD
RasGetErrorStringW PROTO :XWORD,:XWORD,:XWORD
RasGetErrorStringWow PROTO :XWORD,:XWORD,:XWORD
RasGetHport PROTO :XWORD
RasGetLinkStatistics PROTO :XWORD,:XWORD,:XWORD
RasGetProjectionInfoA PROTO :XWORD,:XWORD,:XWORD,:XWORD
RasGetProjectionInfoW PROTO :XWORD,:XWORD,:XWORD,:XWORD
RasGetSubEntryHandleA PROTO :XWORD,:XWORD,:XWORD
RasGetSubEntryHandleW PROTO :XWORD,:XWORD,:XWORD
RasGetSubEntryPropertiesA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasGetSubEntryPropertiesW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasHangUpA PROTO :XWORD
RasHangUpW PROTO :XWORD
RasHangUpWow PROTO :XWORD
RasInvokeEapUI PROTO :XWORD,:XWORD,:XWORD,:XWORD
RasIsRouterConnection PROTO :XWORD
RasIsSharedConnection PROTO :XWORD,:XWORD
RasQueryRedialOnLinkFailure PROTO :XWORD,:XWORD,:XWORD
RasQuerySharedAutoDial PROTO :XWORD
RasQuerySharedConnection PROTO :XWORD
RasRenameEntryA PROTO :XWORD,:XWORD,:XWORD
RasRenameEntryW PROTO :XWORD,:XWORD,:XWORD
RasScriptExecute PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasScriptGetEventCode PROTO :XWORD
RasScriptGetIpAddress PROTO :XWORD,:XWORD
IF (NTDDI_VERSION LT NTDDI_WIN10)
    RasScriptInit PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
    RasScriptReceive PROTO :XWORD,:XWORD,:XWORD
    RasScriptSend PROTO :XWORD,:XWORD,:XWORD
    RasScriptTerm PROTO :XWORD
ENDIF
RasSetAutodialAddressA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasSetAutodialAddressW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasSetAutodialEnableA PROTO :XWORD,:XWORD
RasSetAutodialEnableW PROTO :XWORD,:XWORD
RasSetAutodialParamA PROTO :XWORD,:XWORD,:XWORD
RasSetAutodialParamW PROTO :XWORD,:XWORD,:XWORD
RasSetCredentialsA PROTO :XWORD,:XWORD,:XWORD,:XWORD
RasSetCredentialsW PROTO :XWORD,:XWORD,:XWORD,:XWORD
RasSetCustomAuthDataA PROTO :XWORD,:XWORD,:XWORD,:XWORD
RasSetCustomAuthDataW PROTO :XWORD,:XWORD,:XWORD,:XWORD
RasSetEapUserDataA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasSetEapUserDataW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasSetEntryDialParamsA PROTO :XWORD,:XWORD,:XWORD
RasSetEntryDialParamsW PROTO :XWORD,:XWORD,:XWORD
RasSetEntryPropertiesA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasSetEntryPropertiesW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasSetOldPassword PROTO :XWORD,:XWORD
RasSetSharedAutoDial PROTO :XWORD
RasSetSubEntryPropertiesA PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasSetSubEntryPropertiesW PROTO :XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD,:XWORD
RasValidateEntryNameA PROTO :XWORD,:XWORD
RasValidateEntryNameW PROTO :XWORD,:XWORD
RasfileClose PROTO :XWORD
RasfileDeleteLine PROTO :XWORD
RasfileFindFirstLine PROTO :XWORD,:XWORD,:XWORD
RasfileFindLastLine PROTO :XWORD,:XWORD,:XWORD
RasfileFindMarkedLine PROTO :XWORD,:XWORD
RasfileFindNextKeyLine PROTO :XWORD,:XWORD,:XWORD
RasfileFindNextLine PROTO :XWORD,:XWORD,:XWORD
RasfileFindPrevLine PROTO :XWORD,:XWORD,:XWORD
RasfileFindSectionLine PROTO :XWORD,:XWORD,:XWORD
RasfileGetKeyValueFields PROTO :XWORD,:XWORD,:XWORD
RasfileGetLine PROTO :XWORD
RasfileGetLineMark PROTO :XWORD
RasfileGetLineText PROTO :XWORD,:XWORD
RasfileGetLineType PROTO :XWORD
RasfileGetSectionName PROTO :XWORD,:XWORD
RasfileInsertLine PROTO :XWORD,:XWORD,:XWORD
RasfileLoad PROTO :XWORD,:XWORD,:XWORD,:XWORD
RasfileLoadInfo PROTO :XWORD,:XWORD
RasfilePutKeyValueFields PROTO :XWORD,:XWORD,:XWORD
RasfilePutLineMark PROTO :XWORD,:XWORD
RasfilePutLineText PROTO :XWORD,:XWORD
RasfilePutSectionName PROTO :XWORD,:XWORD
RasfileWrite PROTO :XWORD,:XWORD
SharedAccessResponseListToString PROTO :XWORD,:XWORD
SharedAccessResponseStringToList PROTO :XWORD,:XWORD,:XWORD
UnInitializeRAS PROTO

IFDEF APP_UNICODE
    RASSUBENTRY EQU <RASSUBENTRYW>
    RASCREDENTIALS EQU <RASCREDENTIALSW>
    RASAUTODIALENTRY EQU <RASAUTODIALENTRYW>
    RASCONN EQU <RASCONNW>
    RASCONNSTATUS EQU <RASCONNSTATUSW>
    RASDIALPARAMS EQU <RASDIALPARAMSW>
    RASENTRYNAME EQU <RASENTRYNAMEW>
    RASAMB EQU <RASAMBW>
    RASPPPNBF EQU <RASPPPNBFW>
    RASPPPIPX EQU <RASPPPIPXW>
    RASPPPIP EQU <RASPPPIPW>
    RASSLIP EQU <RASSLIPW>
    RASDEVINFO EQU <RASDEVINFOW>
    RASENTRY EQU <RASENTRYW>
    RasConnectionNotification EQU <RasConnectionNotificationW>
    RasCreatePhonebookEntry EQU <RasCreatePhonebookEntryW>
    RasDeleteEntry EQU <RasDeleteEntryW>
    RasDeleteSubEntry EQU <RasDeleteSubEntryW>
    RasDial EQU <RasDialW>
    RasEditPhonebookEntry EQU <RasEditPhonebookEntryW>
    RasEnumAutodialAddresses EQU <RasEnumAutodialAddressesW>
    RasEnumConnections EQU <RasEnumConnectionsW>
    RasEnumDevices EQU <RasEnumDevicesW>
    RasEnumEntries EQU <RasEnumEntriesW>
    RasFreeEapUserIdentity EQU <RasFreeEapUserIdentityW>
    RasGetAutodialAddress EQU <RasGetAutodialAddressW>
    RasGetAutodialEnable EQU <RasGetAutodialEnableW>
    RasGetAutodialParam EQU <RasGetAutodialParamW>
    RasGetConnectStatus EQU <RasGetConnectStatusW>
    RasGetCountryInfo EQU <RasGetCountryInfoW>
    RasGetCredentials EQU <RasGetCredentialsW>
    RasGetCustomAuthData EQU <RasGetCustomAuthDataW>
    RasGetEapUserData EQU <RasGetEapUserDataW>
    RasGetEapUserIdentity EQU <RasGetEapUserIdentityW>
    RasGetEntryDialParams EQU <RasGetEntryDialParamsW>
    RasGetEntryHrasconn EQU <RasGetEntryHrasconnW>
    RasGetEntryProperties EQU <RasGetEntryPropertiesW>
    RasGetErrorString EQU <RasGetErrorStringW>
    RasGetProjectionInfo EQU <RasGetProjectionInfoW>
    RasGetSubEntryHandle EQU <RasGetSubEntryHandleW>
    RasGetSubEntryProperties EQU <RasGetSubEntryPropertiesW>
    RasHangUp EQU <RasHangUpW>
    RasRenameEntry EQU <RasRenameEntryW>
    RasSetAutodialAddress EQU <RasSetAutodialAddressW>
    RasSetAutodialEnable EQU <RasSetAutodialEnableW>
    RasSetAutodialParam EQU <RasSetAutodialParamW>
    RasSetCredentials EQU <RasSetCredentialsW>
    RasSetCustomAuthData EQU <RasSetCustomAuthDataW>
    RasSetEapUserData EQU <RasSetEapUserDataW>
    RasSetEntryDialParams EQU <RasSetEntryDialParamsW>
    RasSetEntryProperties EQU <RasSetEntryPropertiesW>
    RasSetSubEntryProperties EQU <RasSetSubEntryPropertiesW>
    RasValidateEntryName EQU <RasValidateEntryNameW>
ELSE
    RASSUBENTRY EQU <RASSUBENTRYA>
    RASCREDENTIALS EQU <RASCREDENTIALSA>
    RASAUTODIALENTRY EQU <RASAUTODIALENTRYA>
    RASCONN EQU <RASCONNA>
    RASCONNSTATUS EQU <RASCONNSTATUSA>
    RASDIALPARAMS EQU <RASDIALPARAMSA>
    RASENTRYNAME EQU <RASENTRYNAMEA>
    RASAMB EQU <RASAMBA>
    RASPPPNBF EQU <RASPPPNBFA>
    RASPPPIPX EQU <RASPPPIPXA>
    RASPPPIP EQU <RASPPPIPA>
    RASSLIP EQU <RASSLIPA>
    RASDEVINFO EQU <RASDEVINFOA>
    RASENTRY EQU <RASENTRYA>
    RasConnectionNotification EQU <RasConnectionNotificationA>
    RasCreatePhonebookEntry EQU <RasCreatePhonebookEntryA>
    RasDeleteEntry EQU <RasDeleteEntryA>
    RasDeleteSubEntry EQU <RasDeleteSubEntryA>
    RasDial EQU <RasDialA>
    RasEditPhonebookEntry EQU <RasEditPhonebookEntryA>
    RasEnumAutodialAddresses EQU <RasEnumAutodialAddressesA>
    RasEnumConnections EQU <RasEnumConnectionsA>
    RasEnumDevices EQU <RasEnumDevicesA>
    RasEnumEntries EQU <RasEnumEntriesA>
    RasFreeEapUserIdentity EQU <RasFreeEapUserIdentityA>
    RasGetAutodialAddress EQU <RasGetAutodialAddressA>
    RasGetAutodialEnable EQU <RasGetAutodialEnableA>
    RasGetAutodialParam EQU <RasGetAutodialParamA>
    RasGetConnectStatus EQU <RasGetConnectStatusA>
    RasGetCountryInfo EQU <RasGetCountryInfoA>
    RasGetCredentials EQU <RasGetCredentialsA>
    RasGetCustomAuthData EQU <RasGetCustomAuthDataA>
    RasGetEapUserData EQU <RasGetEapUserDataA>
    RasGetEapUserIdentity EQU <RasGetEapUserIdentityA>
    RasGetEntryDialParams EQU <RasGetEntryDialParamsA>
    RasGetEntryHrasconn EQU <RasGetEntryHrasconnA>
    RasGetEntryProperties EQU <RasGetEntryPropertiesA>
    RasGetErrorString EQU <RasGetErrorStringA>
    RasGetProjectionInfo EQU <RasGetProjectionInfoA>
    RasGetSubEntryHandle EQU <RasGetSubEntryHandleA>
    RasGetSubEntryProperties EQU <RasGetSubEntryPropertiesA>
    RasHangUp EQU <RasHangUpA>
    RasRenameEntry EQU <RasRenameEntryA>
    RasSetAutodialAddress EQU <RasSetAutodialAddressA>
    RasSetAutodialEnable EQU <RasSetAutodialEnableA>
    RasSetAutodialParam EQU <RasSetAutodialParamA>
    RasSetCredentials EQU <RasSetCredentialsA>
    RasSetCustomAuthData EQU <RasSetCustomAuthDataA>
    RasSetEapUserData EQU <RasSetEapUserDataA>
    RasSetEntryDialParams EQU <RasSetEntryDialParamsA>
    RasSetEntryProperties EQU <RasSetEntryPropertiesA>
    RasSetSubEntryProperties EQU <RasSetSubEntryPropertiesA>
    RasValidateEntryName EQU <RasValidateEntryNameA>
ENDIF


;======================= Undocumented functions (unknown arguments) =======================;
;DDMComputeLuid PROTO
;DDMFreeDialingParam PROTO
;DDMFreeRemoteEndpoint PROTO
;DDMFreeRemoteEndpointV2 PROTO
;DDMGetAddressesFromPhonebook PROTO
;DDMGetAddressesFromPhonebookV2 PROTO
;DDMGetEapInfo PROTO
;DDMGetEapUserIdentityW PROTO
;DDMGetPhoneBookContext PROTO
;DDMGetPhonebookInfoV2 PROTO
;DDMGetProtocolStartParams PROTO
;DDMGetRasDialParams PROTO
;DDMGetRasDialingParams PROTO
;DDMGetTunnelEndpoints PROTO
;DDMRasPbkEntryCleanup PROTO
;DDMUpdateProtocolConfigInfoFromEntry PROTO
;DwEnumEntryDetailsEx PROTO
;GetAutoTriggerProfileInfo PROTO
;IsActiveAutoTriggerConnection PROTO
;LaunchVanUIW PROTO
;RasCompleteDialMachineCleanup PROTO
;RasConfigUserProxySettingsW PROTO
;RasFreeEntryAdvancedProperties PROTO
;RasGetAutoTriggerConnectStatus PROTO
;RasGetConnectionErrorStringW PROTO
;RasGetEntryAdvancedProperties PROTO
;RasGetPbkPath PROTO
;RasHandleTriggerConnDisconnect PROTO
;RasRegisterEntryChangeNotification PROTO
;RasSetAutoTriggerProfile PROTO
;RasSetEapUserDataAEx PROTO
;RasSetEapUserDataWEx PROTO
;RasSetEntryAdvancedProperties PROTO
;RasSetPerConnectionProxy PROTO
;RasTriggerConnection PROTO
;RasTriggerConnectionEx PROTO
;RasTriggerDisconnection PROTO
;RasTriggerDisconnectionEx PROTO
;RasUnregisterEntryChangeNotification PROTO

;IFDEF APP_UNICODE
;    RasSetEapUserDataEx EQU <RasSetEapUserDataWEx>
;ELSE
;    RasSetEapUserDataEx EQU <RasSetEapUserDataAEx>
;ENDIF

ENDIF ;RASAPI32_INC
